@@ -1,7 +1,8 @@
 #ifndef SETTINGSDLG_H
 #define SETTINGSDLG_H
+
+#include "settingswidget.h"
 #include <QDialog>
-#include "qtcolorcombobox.h"
 
 
 namespace Ui {
@@ -17,13 +18,14 @@ public:
 protected:
     void changeEvent(QEvent *e);
 
+
 private:
     Ui::settingsdlg *ui;
+    SettingsWidget *pw;
+
 
 
 
-    QtColorComboBox *cbBG;
-    QtColorComboBox *cbtxt;
 
 private slots:
     void on_pbSave_clicked();
